0.9.9 API documentation: Common functions

| 0.9.9 API documentation

- Main Page
- Modules
- Files

Functions
Common functions
Core features

Provides GLSL common functions. More...

## Functions
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | abs (genType x)
| Returns x if x >= 0; otherwise, it returns -x. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL GLM_CONSTEXPR vec< L, T, Q > | abs (vec< L, T, Q > const &x)
| Returns x if x >= 0; otherwise, it returns -x. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | ceil (vec< L, T, Q > const &x)
| Returns a value equal to the nearest integer that is greater than or equal to x. More...
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | clamp (genType x, genType minVal, genType maxVal)
| Returns min(max(x, minVal), maxVal) for each component in x using the floating-point values minVal and maxVal. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL GLM_CONSTEXPR vec< L, T, Q > | clamp (vec< L, T, Q > const &x, T minVal, T maxVal)
| Returns min(max(x, minVal), maxVal) for each component in x using the floating-point values minVal and maxVal. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL GLM_CONSTEXPR vec< L, T, Q > | clamp (vec< L, T, Q > const &x, vec< L, T, Q > const &minVal, vec< L, T, Q > const &maxVal)
| Returns min(max(x, minVal), maxVal) for each component in x using the floating-point values minVal and maxVal. More...
GLM_FUNC_DECL int | floatBitsToInt (float const &v)
| Returns a signed integer value representing the encoding of a floating-point value. More...
template<length_t L, qualifier Q>
GLM_FUNC_DECL vec< L, int, Q > | floatBitsToInt (vec< L, float, Q > const &v)
| Returns a signed integer value representing the encoding of a floating-point value. More...
GLM_FUNC_DECL uint | floatBitsToUint (float const &v)
| Returns a unsigned integer value representing the encoding of a floating-point value. More...
template<length_t L, qualifier Q>
GLM_FUNC_DECL vec< L, uint, Q > | floatBitsToUint (vec< L, float, Q > const &v)
| Returns a unsigned integer value representing the encoding of a floating-point value. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | floor (vec< L, T, Q > const &x)
| Returns a value equal to the nearest integer that is less then or equal to x. More...
template<typename genType >
GLM_FUNC_DECL genType | fma (genType const &a, genType const &b, genType const &c)
| Computes and returns a * b + c. More...
template<typename genType >
GLM_FUNC_DECL genType | fract (genType x)
| Return x - floor(x). More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | fract (vec< L, T, Q > const &x)
| Return x - floor(x). More...
template<typename genType >
GLM_FUNC_DECL genType | frexp (genType x, int &exp)
| Splits x into a floating-point significand in the range [0.5, 1.0) and an integral exponent of two, such that: x = significand * exp(2, exponent) More...
GLM_FUNC_DECL float | intBitsToFloat (int const &v)
| Returns a floating-point value corresponding to a signed integer encoding of a floating-point value. More...
template<length_t L, qualifier Q>
GLM_FUNC_DECL vec< L, float, Q > | intBitsToFloat (vec< L, int, Q > const &v)
| Returns a floating-point value corresponding to a signed integer encoding of a floating-point value. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, bool, Q > | isinf (vec< L, T, Q > const &x)
| Returns true if x holds a positive infinity or negative infinity representation in the underlying implementation's set of floating point representations. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, bool, Q > | isnan (vec< L, T, Q > const &x)
| Returns true if x holds a NaN (not a number) representation in the underlying implementation's set of floating point representations. More...
template<typename genType >
GLM_FUNC_DECL genType | ldexp (genType const &x, int const &exp)
| Builds a floating-point number from x and the corresponding integral exponent of two in exp, returning: significand * exp(2, exponent) More...
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | max (genType x, genType y)
| Returns y if x < y; otherwise, it returns x. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL GLM_CONSTEXPR vec< L, T, Q > | max (vec< L, T, Q > const &x, T y)
| Returns y if x < y; otherwise, it returns x. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL GLM_CONSTEXPR vec< L, T, Q > | max (vec< L, T, Q > const &x, vec< L, T, Q > const &y)
| Returns y if x < y; otherwise, it returns x. More...
template<typename genType >
GLM_FUNC_DECL GLM_CONSTEXPR genType | min (genType x, genType y)
| Returns y if y < x; otherwise, it returns x. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL GLM_CONSTEXPR vec< L, T, Q > | min (vec< L, T, Q > const &x, T y)
| Returns y if y < x; otherwise, it returns x. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL GLM_CONSTEXPR vec< L, T, Q > | min (vec< L, T, Q > const &x, vec< L, T, Q > const &y)
| Returns y if y < x; otherwise, it returns x. More...
template<typename genTypeT , typename genTypeU >
GLM_FUNC_DECL genTypeT | mix (genTypeT x, genTypeT y, genTypeU a)
| If genTypeU is a floating scalar or vector: Returns x * (1.0 - a) + y * a, i.e., the linear blend of x and y using the floating-point value a. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | mod (vec< L, T, Q > const &x, vec< L, T, Q > const &y)
| Modulus. More...
template<typename genType >
GLM_FUNC_DECL genType | modf (genType x, genType &i)
| Returns the fractional part of x and sets i to the integer part (as a whole number floating point value). More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | round (vec< L, T, Q > const &x)
| Returns a value equal to the nearest integer to x. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | roundEven (vec< L, T, Q > const &x)
| Returns a value equal to the nearest integer to x. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | sign (vec< L, T, Q > const &x)
| Returns 1.0 if x > 0, 0.0 if x == 0, or -1.0 if x < 0. More...
template<typename genType >
GLM_FUNC_DECL genType | smoothstep (genType edge0, genType edge1, genType x)
| Returns 0.0 if x <= edge0 and 1.0 if x >= edge1 and performs smooth Hermite interpolation between 0 and 1 when edge0 < x < edge1. More...
template<typename genType >
GLM_FUNC_DECL genType | step (genType edge, genType x)
| Returns 0.0 if x < edge, otherwise it returns 1.0 for each component of a genType. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | step (T edge, vec< L, T, Q > const &x)
| Returns 0.0 if x < edge, otherwise it returns 1.0. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | step (vec< L, T, Q > const &edge, vec< L, T, Q > const &x)
| Returns 0.0 if x < edge, otherwise it returns 1.0. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | trunc (vec< L, T, Q > const &x)
| Returns a value equal to the nearest integer to x whose absolute value is not larger than the absolute value of x. More...
GLM_FUNC_DECL float | uintBitsToFloat (uint const &v)
| Returns a floating-point value corresponding to a unsigned integer encoding of a floating-point value. More...
template<length_t L, qualifier Q>
GLM_FUNC_DECL vec< L, float, Q > | uintBitsToFloat (vec< L, uint, Q > const &v)
| Returns a floating-point value corresponding to a unsigned integer encoding of a floating-point value. More...

## Detailed Description

Provides GLSL common functions.

These all operate component-wise. The description is per component.

Include <glm/common.hpp> to use these core features.

## Function Documentation

GLM_FUNC_DECL GLM_CONSTEXPR genType glm::abs | ( | genType | x | ) |

Returns x if x >= 0; otherwise, it returns -x.

Template Parameters

  genType | floating-point or signed integer; scalar or vector types.

See also
  GLSL abs man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL GLM_CONSTEXPR vec<L, T, Q> glm::abs | ( | vec< L, T, Q > const & | x | ) |

Returns x if x >= 0; otherwise, it returns -x.

Template Parameters

  L | Integer between 1 and 4 included that qualify the dimension of the vector
  T | Floating-point or signed integer scalar types
  Q | Value from qualifier enum

See also
  GLSL abs man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL vec<L, T, Q> glm::ceil | ( | vec< L, T, Q > const & | x | ) |

Returns a value equal to the nearest integer that is greater than or equal to x.

Template Parameters

  L | Integer between 1 and 4 included that qualify the dimension of the vector
  T | Floating-point scalar types
  Q | Value from qualifier enum

See also
  GLSL ceil man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL GLM_CONSTEXPR genType glm::clamp | ( | genType | x,
|  | genType | minVal,
|  | genType | maxVal
| ) |  |

Returns min(max(x, minVal), maxVal) for each component in x using the floating-point values minVal and maxVal.

Template Parameters

  genType | Floating-point or integer; scalar or vector types.

See also
  GLSL clamp man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

Referenced by glm::saturate().

GLM_FUNC_DECL GLM_CONSTEXPR vec<L, T, Q> glm::clamp | ( | vec< L, T, Q > const & | x,
|  | T | minVal,
|  | T | maxVal
| ) |  |

Returns min(max(x, minVal), maxVal) for each component in x using the floating-point values minVal and maxVal.

Template Parameters

  L | Integer between 1 and 4 included that qualify the dimension of the vector
  T | Floating-point or integer scalar types
  Q | Value from qualifier enum

See also
  GLSL clamp man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL GLM_CONSTEXPR vec<L, T, Q> glm::clamp | ( | vec< L, T, Q > const & | x,
|  | vec< L, T, Q > const & | minVal,
|  | vec< L, T, Q > const & | maxVal
| ) |  |

Returns min(max(x, minVal), maxVal) for each component in x using the floating-point values minVal and maxVal.

Template Parameters

  L | Integer between 1 and 4 included that qualify the dimension of the vector
  T | Floating-point or integer scalar types
  Q | Value from qualifier enum

See also
  GLSL clamp man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL int glm::floatBitsToInt | ( | float const & | v | ) |

Returns a signed integer value representing the encoding of a floating-point value.

The floating-point value's bit-level representation is preserved.

See also
  GLSL floatBitsToInt man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL vec<L, int, Q> glm::floatBitsToInt | ( | vec< L, float, Q > const & | v | ) |

Returns a signed integer value representing the encoding of a floating-point value.

The floatingpoint value's bit-level representation is preserved.

Template Parameters

  L | Integer between 1 and 4 included that qualify the dimension of the vector
  Q | Value from qualifier enum

See also
  GLSL floatBitsToInt man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL uint glm::floatBitsToUint | ( | float const & | v | ) |

Returns a unsigned integer value representing the encoding of a floating-point value.

The floatingpoint value's bit-level representation is preserved.

See also
  GLSL floatBitsToUint man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL vec<L, uint, Q> glm::floatBitsToUint | ( | vec< L, float, Q > const & | v | ) |

Returns a unsigned integer value representing the encoding of a floating-point value.

The floatingpoint value's bit-level representation is preserved.

Template Parameters

  L | Integer between 1 and 4 included that qualify the dimension of the vector
  Q | Value from qualifier enum

See also
  GLSL floatBitsToUint man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL vec<L, T, Q> glm::floor | ( | vec< L, T, Q > const & | x | ) |

Returns a value equal to the nearest integer that is less then or equal to x.

Template Parameters

  L | Integer between 1 and 4 included that qualify the dimension of the vector
  T | Floating-point scalar types
  Q | Value from qualifier enum

See also
  GLSL floor man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL genType glm::fma | ( | genType const & | a,
|  | genType const & | b,
|  | genType const & | c
| ) |  |

Computes and returns a * b + c.

Template Parameters

  genType | Floating-point scalar or vector types.

See also
  GLSL fma man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL genType glm::fract | ( | genType | x | ) |

Return x - floor(x).

Template Parameters

  genType | Floating-point scalar or vector types.

See also
  GLSL fract man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL vec<L, T, Q> glm::fract | ( | vec< L, T, Q > const & | x | ) |

Return x - floor(x).

Template Parameters

  L | Integer between 1 and 4 included that qualify the dimension of the vector
  T | Floating-point scalar types
  Q | Value from qualifier enum

See also
  GLSL fract man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL genType glm::frexp | ( | genType | x,
|  | int & | exp
| ) |  |

Splits x into a floating-point significand in the range [0.5, 1.0) and an integral exponent of two, such that: x = significand * exp(2, exponent)

The significand is returned by the function and the exponent is returned in the parameter exp. For a floating-point value of zero, the significant and exponent are both zero. For a floating-point value that is an infinity or is not a number, the results are undefined.

Template Parameters

  genType | Floating-point scalar or vector types.

See also
  GLSL frexp man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL float glm::intBitsToFloat | ( | int const & | v | ) |

Returns a floating-point value corresponding to a signed integer encoding of a floating-point value.

If an inf or NaN is passed in, it will not signal, and the resulting floating point value is unspecified. Otherwise, the bit-level representation is preserved.

See also
  GLSL intBitsToFloat man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL vec<L, float, Q> glm::intBitsToFloat | ( | vec< L, int, Q > const & | v | ) |

Returns a floating-point value corresponding to a signed integer encoding of a floating-point value.

If an inf or NaN is passed in, it will not signal, and the resulting floating point value is unspecified. Otherwise, the bit-level representation is preserved.

Template Parameters

  L | Integer between 1 and 4 included that qualify the dimension of the vector
  Q | Value from qualifier enum

See also
  GLSL intBitsToFloat man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL vec<L, bool, Q> glm::isinf | ( | vec< L, T, Q > const & | x | ) |

Returns true if x holds a positive infinity or negative infinity representation in the underlying implementation's set of floating point representations.

Returns false otherwise, including for implementations with no infinity representations.

Template Parameters

  L | Integer between 1 and 4 included that qualify the dimension of the vector
  T | Floating-point scalar types
  Q | Value from qualifier enum

See also
  GLSL isinf man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL vec<L, bool, Q> glm::isnan | ( | vec< L, T, Q > const & | x | ) |

Returns true if x holds a NaN (not a number) representation in the underlying implementation's set of floating point representations.

Returns false otherwise, including for implementations with no NaN representations.

/!\ When using compiler fast math, this function may fail.

Template Parameters

  L | Integer between 1 and 4 included that qualify the dimension of the vector
  T | Floating-point scalar types
  Q | Value from qualifier enum

See also
  GLSL isnan man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL genType glm::ldexp | ( | genType const & | x,
|  | int const & | exp
| ) |  |

Builds a floating-point number from x and the corresponding integral exponent of two in exp, returning: significand * exp(2, exponent)

If this product is too large to be represented in the floating-point type, the result is undefined.

Template Parameters

  genType | Floating-point scalar or vector types.

See also
  GLSL ldexp man page;
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL GLM_CONSTEXPR genType glm::max | ( | genType | x,
|  | genType | y
| ) |  |

Returns y if x < y; otherwise, it returns x.

Template Parameters

  genType | Floating-point or integer; scalar or vector types.

See also
  GLSL max man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL GLM_CONSTEXPR vec<L, T, Q> glm::max | ( | vec< L, T, Q > const & | x,
|  | T | y
| ) |  |

Returns y if x < y; otherwise, it returns x.

Template Parameters

  L | Integer between 1 and 4 included that qualify the dimension of the vector
  T | Floating-point or integer scalar types
  Q | Value from qualifier enum

See also
  GLSL max man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL GLM_CONSTEXPR vec<L, T, Q> glm::max | ( | vec< L, T, Q > const & | x,
|  | vec< L, T, Q > const & | y
| ) |  |

Returns y if x < y; otherwise, it returns x.

Template Parameters

  L | Integer between 1 and 4 included that qualify the dimension of the vector
  T | Floating-point or integer scalar types
  Q | Value from qualifier enum

See also
  GLSL max man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL GLM_CONSTEXPR genType glm::min | ( | genType | x,
|  | genType | y
| ) |  |

Returns y if y < x; otherwise, it returns x.

Template Parameters

  genType | Floating-point or integer; scalar or vector types.

See also
  GLSL min man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL GLM_CONSTEXPR vec<L, T, Q> glm::min | ( | vec< L, T, Q > const & | x,
|  | T | y
| ) |  |

Returns y if y < x; otherwise, it returns x.

Template Parameters

  L | Integer between 1 and 4 included that qualify the dimension of the vector
  T | Floating-point or integer scalar types
  Q | Value from qualifier enum

See also
  GLSL min man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL GLM_CONSTEXPR vec<L, T, Q> glm::min | ( | vec< L, T, Q > const & | x,
|  | vec< L, T, Q > const & | y
| ) |  |

Returns y if y < x; otherwise, it returns x.

Template Parameters

  L | Integer between 1 and 4 included that qualify the dimension of the vector
  T | Floating-point or integer scalar types
  Q | Value from qualifier enum

See also
  GLSL min man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL genTypeT glm::mix | ( | genTypeT | x,
|  | genTypeT | y,
|  | genTypeU | a
| ) |  |

If genTypeU is a floating scalar or vector: Returns x * (1.0 - a) + y * a, i.e., the linear blend of x and y using the floating-point value a.

The value for a is not restricted to the range [0, 1].

If genTypeU is a boolean scalar or vector: Selects which vector each returned component comes from. For a component of 'a' that is false, the corresponding component of 'x' is returned. For a component of 'a' that is true, the corresponding component of 'y' is returned. Components of 'x' and 'y' that are not selected are allowed to be invalid floating point values and will have no effect on the results. Thus, this provides different functionality than genType mix(genType x, genType y, genType(a)) where a is a Boolean vector.

See also
  GLSL mix man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

Parameters

  [in] | x | Value to interpolate.
  [in] | y | Value to interpolate.
  [in] | a | Interpolant.

Template Parameters

  genTypeT | Floating point scalar or vector.
  genTypeU | Floating point or boolean scalar or vector. It can't be a vector if it is the length of genTypeT.

#include <glm/glm.hpp>
...
float a;
bool b;
glm::dvec3 e;
glm::dvec3 f;
glm::vec4 g;
glm::vec4 h;
...
glm::vec4 r = glm::mix(g, h, a); // Interpolate with a floating-point scalar two vectors.
glm::vec4 s = glm::mix(g, h, b); // Returns g or h;
glm::dvec3 t = glm::mix(e, f, a); // Types of the third parameter is not required to match with the first and the second.
glm::vec4 u = glm::mix(g, h, r); // Interpolations can be perform per component with a vector for the last parameter.

Referenced by glm::lerp().

GLM_FUNC_DECL vec<L, T, Q> glm::mod | ( | vec< L, T, Q > const & | x,
|  | vec< L, T, Q > const & | y
| ) |  |

Modulus.

Returns x - y * floor(x / y) for each component in x using the floating point value y.

Template Parameters

  L | Integer between 1 and 4 included that qualify the dimension of the vector
  T | Floating-point scalar types, include glm/gtc/integer for integer scalar types support
  Q | Value from qualifier enum

See also
  GLSL mod man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL genType glm::modf | ( | genType | x,
|  | genType & | i
| ) |  |

Returns the fractional part of x and sets i to the integer part (as a whole number floating point value).

Both the return value and the output parameter will have the same sign as x.

Template Parameters

  genType | Floating-point scalar or vector types.

See also
  GLSL modf man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL vec<L, T, Q> glm::round | ( | vec< L, T, Q > const & | x | ) |

Returns a value equal to the nearest integer to x.

The fraction 0.5 will round in a direction chosen by the implementation, presumably the direction that is fastest. This includes the possibility that round(x) returns the same value as roundEven(x) for all values of x.

Template Parameters

  L | Integer between 1 and 4 included that qualify the dimension of the vector
  T | Floating-point scalar types
  Q | Value from qualifier enum

See also
  GLSL round man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL vec<L, T, Q> glm::roundEven | ( | vec< L, T, Q > const & | x | ) |

Returns a value equal to the nearest integer to x.

A fractional part of 0.5 will round toward the nearest even integer. (Both 3.5 and 4.5 for x will return 4.0.)

Template Parameters

  L | Integer between 1 and 4 included that qualify the dimension of the vector
  T | Floating-point scalar types
  Q | Value from qualifier enum

See also
  GLSL roundEven man page
  GLSL 4.20.8 specification, section 8.3 Common Functions
  New round to even technique

GLM_FUNC_DECL vec<L, T, Q> glm::sign | ( | vec< L, T, Q > const & | x | ) |

Returns 1.0 if x > 0, 0.0 if x == 0, or -1.0 if x < 0.

Template Parameters

  L | Integer between 1 and 4 included that qualify the dimension of the vector
  T | Floating-point scalar types
  Q | Value from qualifier enum

See also
  GLSL sign man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL genType glm::smoothstep | ( | genType | edge0,
|  | genType | edge1,
|  | genType | x
| ) |  |

Returns 0.0 if x <= edge0 and 1.0 if x >= edge1 and performs smooth Hermite interpolation between 0 and 1 when edge0 < x < edge1.

This is useful in cases where you would want a threshold function with a smooth transition. This is equivalent to: genType t; t = clamp ((x - edge0) / (edge1 - edge0), 0, 1); return t * t * (3 - 2 * t); Results are undefined if edge0 >= edge1.

Template Parameters

  genType | Floating-point scalar or vector types.

See also
  GLSL smoothstep man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL genType glm::step | ( | genType | edge,
|  | genType | x
| ) |  |

Returns 0.0 if x < edge, otherwise it returns 1.0 for each component of a genType.

See also
  GLSL step man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL vec<L, T, Q> glm::step | ( | T | edge,
|  | vec< L, T, Q > const & | x
| ) |  |

Returns 0.0 if x < edge, otherwise it returns 1.0.

Template Parameters

  L | Integer between 1 and 4 included that qualify the dimension of the vector
  T | Floating-point scalar types
  Q | Value from qualifier enum

See also
  GLSL step man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL vec<L, T, Q> glm::step | ( | vec< L, T, Q > const & | edge,
|  | vec< L, T, Q > const & | x
| ) |  |

Returns 0.0 if x < edge, otherwise it returns 1.0.

Template Parameters

  L | Integer between 1 and 4 included that qualify the dimension of the vector
  T | Floating-point scalar types
  Q | Value from qualifier enum

See also
  GLSL step man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL vec<L, T, Q> glm::trunc | ( | vec< L, T, Q > const & | x | ) |

Returns a value equal to the nearest integer to x whose absolute value is not larger than the absolute value of x.

Template Parameters

  L | Integer between 1 and 4 included that qualify the dimension of the vector
  T | Floating-point scalar types
  Q | Value from qualifier enum

See also
  GLSL trunc man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL float glm::uintBitsToFloat | ( | uint const & | v | ) |

Returns a floating-point value corresponding to a unsigned integer encoding of a floating-point value.

If an inf or NaN is passed in, it will not signal, and the resulting floating point value is unspecified. Otherwise, the bit-level representation is preserved.

See also
  GLSL uintBitsToFloat man page
  GLSL 4.20.8 specification, section 8.3 Common Functions

GLM_FUNC_DECL vec<L, float, Q> glm::uintBitsToFloat | ( | vec< L, uint, Q > const & | v | ) |

Returns a floating-point value corresponding to a unsigned integer encoding of a floating-point value.

If an inf or NaN is passed in, it will not signal, and the resulting floating point value is unspecified. Otherwise, the bit-level representation is preserved.

Template Parameters

  L | Integer between 1 and 4 included that qualify the dimension of the vector
  Q | Value from qualifier enum

See also
  GLSL uintBitsToFloat man page
  GLSL 4.20.8 specification, section 8.3 Common Functions